@@ -80,7 +80,11 @@ e_cal_backend_ews_populate_windows_zones (void)
 		return;
 	}
 
-	filename = g_build_filename (EXCHANGE_EWS_DATADIR, "windowsZones.xml", NULL);
+	if (g_strcmp0 (g_getenv ("EWS_INTERNAL_TEST"), "1") == 0)
+		filename = g_build_filename (EXCHANGE_EWS_SRCDIR, "windowsZones.xml", NULL);
+	else
+		filename = g_build_filename (EXCHANGE_EWS_DATADIR, "windowsZones.xml", NULL);
+
 	doc = xmlReadFile (filename, NULL, 0);
 
 	if (doc == NULL) {
@@ -2245,7 +2249,7 @@ e_cal_backend_ews_get_datetime_with_zone (ETimezoneCache *timezone_cache,
 
 	dt = get_func (prop);
 
-	if (dt || !i_cal_time_is_valid_time (dt) ||
+	if (!dt || !i_cal_time_is_valid_time (dt) ||
 	    i_cal_time_is_null_time (dt)) {
 		g_clear_object (&dt);
 		g_object_unref (prop);
@@ -2286,6 +2290,8 @@ e_cal_backend_ews_get_datetime_with_zone (ETimezoneCache *timezone_cache,
 
 	if (!zone)
 		zone = vcalendar ? i_cal_component_get_timezone (vcalendar, tzid) : NULL;
+	else
+		g_object_ref (zone);
 
 	i_cal_time_set_timezone (dt, zone);
 
